@@ -15,10 +15,13 @@ class HardwareType(str, Enum):
     K80 = "K80"
     V100 = "V100"
     T4 = "T4"
+    A10G = "A10G"
     A100_80G = "A100 80GB GCP"
     A100_40G = "A100 40GB GCP"
     CPU = "CPU"
     EPYC = "EPYC"
+    EPYC_7002 = "EPYC 7002"
+    EPYC_7003 = "EPYC 7003"
     XAVIER = "Jetson Xavier"
     NANO = "Jetson Nano"
     XAVIER_AGX = "Jetson Xavier AGX"
@@ -26,6 +29,7 @@ class HardwareType(str, Enum):
     CASCADE_LAKE = "Cascade Lake"
     SKYLAKE = "Skylake"
     Broadwell = "Broadwell"
+    Icelake = "Icelake"
     NUC_TIGER_LAKE = "Intel NUC Tiger Lake"
 
     HAILO8 = "Hailo-8"
@@ -76,16 +80,51 @@ class HardwareTypeLabel(str, Enum):
     XAVIER_AGX = "Jetson AGX Xavier 32GB"
     ORIN = "Jetson AGX Orin Development Kit"
 
+    K80 = HardwareType.K80.value
+    V100 = HardwareType.V100.value
+    T4 = HardwareType.T4.value
+    A10G = HardwareType.A10G.value
+    A100_80G = HardwareType.A100_80G.value
+    A100_40G = HardwareType.A100_40G.value
+    CPU = HardwareType.CPU.value
+    EPYC = HardwareType.EPYC.value
+    EPYC_7002 = HardwareType.EPYC_7002.value
+    EPYC_7003 = HardwareType.EPYC_7003.value
+    CASCADE_LAKE = HardwareType.CASCADE_LAKE.value
+    SKYLAKE = HardwareType.SKYLAKE.value
+    Broadwell = HardwareType.Broadwell.value
+    Icelake = HardwareType.Icelake.value
+    NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
+
+    HAILO8 = HardwareType.HAILO8.value
+    AMBARELLA = HardwareType.AMBARELLA.value
+    APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
+    APPLE_IPHONE_A12 = HardwareType.APPLE_IPHONE_A12.value
+    APPLE_IPHONE_A14 = HardwareType.APPLE_IPHONE_A14.value
+    APPLE_IPHONE_A15 = HardwareType.APPLE_IPHONE_A15.value
+    SNAPDRAGON_845 = HardwareType.SNAPDRAGON_845.value
+    SNAPDRAGON_855 = HardwareType.SNAPDRAGON_855.value
+    SNAPDRAGON_885 = HardwareType.SNAPDRAGON_885.value
+    SNAPDRAGON_8_GEN_1 = HardwareType.SNAPDRAGON_8_GEN_1.value
+    EXYNOS_9810 = HardwareType.EXYNOS_9810.value
+    EXYNOS_9820 = HardwareType.EXYNOS_9820.value
+    EXYNOS_990 = HardwareType.EXYNOS_990.value
+    EXYNOS_2200 = HardwareType.EXYNOS_2200.value
+
 
 class HardwareMachineModel(str, Enum):
     K80 = "p2.xlarge"
     V100 = "p3.2xlarge"
     T4 = "g4dn.2xlarge"
+    A10G = "g5.2xlarge"
     CPU = "c5.4xlarge"
     EPYC = "c5a.2xlarge"
     CASCADE_LAKE = "c5.4xlarge"
     SKYLAKE = "c5n.4xlarge"
     Broadwell = "m4.4xlarge"
+    Icelake = "m6i.4xlarge"
+    EPYC_7002 = "c5a.4xlarge"
+    EPYC_7003 = "m6a.4xlarge"
 
     NANO = HardwareType.NANO.value
     XAVIER = HardwareType.XAVIER.value
@@ -124,6 +163,7 @@ class MapHardwareTypeToFamily(str, Enum):
     V100 = InferenceHardware.GPU.value
     K80 = InferenceHardware.GPU.value
     T4 = InferenceHardware.GPU.value
+    A10G = InferenceHardware.GPU.value
     A100_80G = InferenceHardware.GPU.value
     A100_40G = InferenceHardware.GPU.value
     NANO = InferenceHardware.GPU.value
@@ -134,9 +174,12 @@ class MapHardwareTypeToFamily(str, Enum):
     # CPUs
     CPU = InferenceHardware.CPU.value
     EPYC = InferenceHardware.CPU.value
+    EPYC_7002 = InferenceHardware.CPU.value
+    EPYC_7003 = InferenceHardware.CPU.value
     CASCADE_LAKE = InferenceHardware.CPU.value
     SKYLAKE = InferenceHardware.CPU.value
     Broadwell = InferenceHardware.CPU.value
+    Icelake = InferenceHardware.CPU.value
     NUC_TIGER_LAKE = InferenceHardware.CPU.value
 
 
@@ -153,6 +196,7 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     V100 = InferyVersion.GPU.value
     K80 = InferyVersion.GPU.value
     T4 = InferyVersion.GPU.value
+    A10G = InferyVersion.GPU.value
     A100_80G = InferyVersion.GPU.value
     A100_40G = InferyVersion.GPU.value
 
@@ -165,9 +209,12 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     # CPUs
     CPU = InferyVersion.CPU.value
     EPYC = InferyVersion.CPU.value
+    EPYC_7002 = InferyVersion.CPU.value
+    EPYC_7003 = InferyVersion.CPU.value
     CASCADE_LAKE = InferyVersion.CPU.value
     SKYLAKE = InferyVersion.CPU.value
     Broadwell = InferyVersion.CPU.value
+    Icelake = InferyVersion.CPU.value
     NUC_TIGER_LAKE = InferyVersion.CPU.value
 
 
@@ -189,6 +236,7 @@ class HardwareTaint(str, Enum):
     V100 = "nvidia.com/v100gpu"
     K80 = "nvidia.com/k80gpu"
     T4 = "nvidia.com/t4gpu"
+    A10G = "nvidia.com/a10gpu"
     A100_80G = UNKNOWN
     A100_40G = UNKNOWN
     NANO = "nvidia.com/jetson-nano"
@@ -196,10 +244,14 @@ class HardwareTaint(str, Enum):
     XAVIER_AGX = "nvidia.com/jetson-xavier-agx"
     ORIN = "nvidia.com/jetson-orin"
     # CPUs
+    CPU = UNKNOWN
     EPYC = "amd.com/epyc"
+    EPYC_7002 = "amd.com/7002"
+    EPYC_7003 = "amd.com/7003"
     CASCADE_LAKE = "intel.com/cascade-lake"
     SKYLAKE = "intel.com/skylake"
     Broadwell = "intel.com/broadwell"
+    Icelake = "intel.com/icelake"
     NUC_TIGER_LAKE = "intel.com/nuc-tiger-lake"
 
 
@@ -208,19 +260,23 @@ class HardwareLabel(str, Enum):
     V100 = "nvidia-tesla-v100"
     K80 = "nvidia-tesla-k80"
     T4 = "nvidia-tesla-t4"
+    A10G = "nvidia-ampere-a10"
     A100_80G = UNKNOWN
     A100_40G = UNKNOWN
-    M60 = "nvidia-m60"
     NANO = "nvidia-jetson-nano"
     XAVIER = "nvidia-jetson-xavier"
     XAVIER_AGX = "nvidia-jetson-xavier-agx"
     ORIN = "nvidia-jetson-orin"
 
     # CPUs
+    CPU = UNKNOWN
     EPYC = "amd-epyc"
+    EPYC_7002 = "amd-epyc-7002"
+    EPYC_7003 = "amd-epyc-7003"
     CASCADE_LAKE = "intel-cascade-lake"
     SKYLAKE = "intel-skylake"
     Broadwell = "intel-broadwell"
+    Icelake = "intel-icelake"
     NUC_TIGER_LAKE = "intel-nuc-tiger-lake"
 
 
@@ -228,9 +284,13 @@ class MapHardwareTypeToVendor(str, Enum):
     V100 = HardwareVendor.NVIDIA.value
     K80 = HardwareVendor.NVIDIA.value
     T4 = HardwareVendor.NVIDIA.value
+    A10G = HardwareVendor.NVIDIA.value
     A100_80G = HardwareVendor.NVIDIA.value
     A100_40G = HardwareVendor.NVIDIA.value
+    CPU = HardwareVendor.AMD.value
     EPYC = HardwareVendor.AMD.value
+    EPYC_7002 = HardwareVendor.AMD.value
+    EPYC_7003 = HardwareVendor.AMD.value
     NANO = HardwareVendor.NVIDIA.value
     XAVIER = HardwareVendor.NVIDIA.value
     XAVIER_AGX = HardwareVendor.NVIDIA.value
@@ -238,6 +298,7 @@ class MapHardwareTypeToVendor(str, Enum):
     CASCADE_LAKE = HardwareVendor.INTEL.value
     SKYLAKE = HardwareVendor.INTEL.value
     Broadwell = HardwareVendor.INTEL.value
+    Icelake = HardwareVendor.INTEL.value
     NUC_TIGER_LAKE = HardwareVendor.INTEL.value
 
 
@@ -246,10 +307,17 @@ class MapHardwareTypeToEnvironment(str, Enum):
     V100 = HardwareEnvironment.AWS.value
     K80 = HardwareEnvironment.AWS.value
     T4 = HardwareEnvironment.AWS.value
+    A10G = HardwareEnvironment.AWS.value
+    A100_40G = HardwareEnvironment.GCP.value
+    A100_80G = HardwareEnvironment.GCP.value
+    CPU = HardwareEnvironment.AWS.value
     EPYC = HardwareEnvironment.AWS.value
+    EPYC_7002 = HardwareEnvironment.AWS.value
+    EPYC_7003 = HardwareEnvironment.AWS.value
     CASCADE_LAKE = HardwareEnvironment.AWS.value
     SKYLAKE = HardwareEnvironment.AWS.value
     Broadwell = HardwareEnvironment.AWS.value
+    Icelake = HardwareEnvironment.AWS.value
 
     # PREMISE
     NANO = HardwareEnvironment.PREMISE.value
@@ -263,9 +331,13 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
     V100 = get_enum_values(BatchSize)
     K80 = get_enum_values(BatchSize)
     T4 = get_enum_values(BatchSize)
+    A10G = get_enum_values(BatchSize)
     A100_80G = get_enum_values(BatchSize)
     A100_40G = get_enum_values(BatchSize)
+    CPU = get_enum_values(BatchSize)
     EPYC = get_enum_values(BatchSize)
+    EPYC_7002 = get_enum_values(BatchSize)
+    EPYC_7003 = get_enum_values(BatchSize)
     NANO = get_enum_values(BatchSizeEdge)
     XAVIER = get_enum_values(BatchSizeEdge)
     XAVIER_AGX = get_enum_values(BatchSizeEdge)
@@ -273,6 +345,7 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
     CASCADE_LAKE = get_enum_values(BatchSize)
     SKYLAKE = get_enum_values(BatchSize)
     Broadwell = get_enum_values(BatchSize)
+    Icelake = get_enum_values(BatchSize)
     NUC_TIGER_LAKE = get_enum_values(BatchSize)
 
 
@@ -310,6 +383,7 @@ class MapHardwareTypeToGroup(str, Enum):
     K80 = HardwareGroup.GPU.value
     V100 = HardwareGroup.GPU.value
     T4 = HardwareGroup.GPU.value
+    A10G = HardwareGroup.GPU.value
     A100_80G = HardwareGroup.GPU.value
     A100_40G = HardwareGroup.GPU.value
 
@@ -323,9 +397,12 @@ class MapHardwareTypeToGroup(str, Enum):
 
     CPU = HardwareGroup.CPU.value
     EPYC = HardwareGroup.CPU.value
+    EPYC_7002 = HardwareGroup.CPU.value
+    EPYC_7003 = HardwareGroup.CPU.value
     CASCADE_LAKE = HardwareGroup.CPU.value
     SKYLAKE = HardwareGroup.CPU.value
     Broadwell = HardwareGroup.CPU.value
+    Icelake = HardwareGroup.CPU.value
 
     APPLE_IPHONE_A11 = HardwareGroup.CONSUMER_EDGE.value
     APPLE_IPHONE_A12 = HardwareGroup.CONSUMER_EDGE.value
